@@ -13,11 +13,11 @@ def knn_laplacian(
     Parameters
     ----------
     image: numpy.ndarray
-        Image
+        Image with shape :math:`h\\times w \\times 3`
     n_neighbors: list of ints
-        Number of neighbors to consider
+        Number of neighbors to consider. If :code:`len(n_neighbors)>1` multiple nearest neighbor calculations are done and merged, defaults to `[20, 10]`, i.e. first 20 neighbors are considered and in the second run :math:`10` neighbors. The pixel distances are then weighted by the :code:`distance_weights`.
     distance_weights: list of floats
-        Weight of distance in feature vector
+        Weight of distance in feature vector, defaults to `[2.0, 0.1]`.
 
     Returns
     ---------
