@@ -14,7 +14,9 @@ def uniform_laplacian(image, radius=1):
     image: numpy.ndarray
         Image with shape :math:`h\\times w \\times 3`
     radius: int
-        Local window size, defaults to 1
+        Radius of local window size, defaults to 1, i.e. only adjacent pixels are considered.
+       The size of the local window is given as :math:`(2 r + 1)^2`, where :math:`r` denotes         the radius. A larger radius might lead to violated color line constraints, but also 
+       favors further propagation of information within the image.
 
     Returns
     -------
