@@ -11,6 +11,15 @@ def jacobi(A):
     ---------
     precondition_matvec: function
         Function which applies the Jacobi preconditioner to a vector
+
+    Example
+    -------
+    >>> from pymatting import *
+    >>> import numpy as np
+    >>> A = np.array([[2, 3], [3, 5]])
+    >>> preconditioner = jacobi(A)
+    >>> preconditioner(np.array([1, 2]))
+    array([0.5, 0.4])
     """
     diagonal = A.diagonal()
 
